@@ -15,7 +15,7 @@ use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 use File::chdir;
 
-our $VERSION     = version->new('0.4.3');
+our $VERSION     = version->new('0.5.0');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -112,6 +112,14 @@ sub versions {
     return @versions;
 }
 
+sub add {
+    my ($self, $file, $revision) = @_;
+
+    my $exe = $self->exe;
+    my $rev = $revision ? "-r$revision " : '';
+
+    return `$exe add $rev$file`;
+}
 
 1;
 
@@ -123,7 +131,7 @@ VCS::Which::Plugin - Base class for the various VCS plugins
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin version 0.4.3.
+This documentation refers to VCS::Which::Plugin version 0.5.0.
 
 
 =head1 SYNOPSIS
